@@ -30,6 +30,7 @@ import time
 import wx
 import calendar
 import re
+import threading
 
 
 class RedirectedOutput(object):
@@ -256,12 +257,25 @@ class Application(object):
                                           value)
         
     def __register_signal_handlers(self):
-        quit_adapter = lambda *args: self.quitApplication()
         if operating_system.isWindows():
             import win32api  # pylint: disable=F0401
+            def quit_adapter(*args):
+                # The handler is called from something that is not the main thread, so we can't do
+                # much wx-related
+                event = threading.Event()
+                def quit():
+                    try:
+                        self.quitApplication()
+                    finally:
+                        event.set()
+                wx.CallAfter(quit)
+                event.wait()
+                return True
             win32api.SetConsoleCtrlHandler(quit_adapter, True)
         else:
             import signal
+            def quit_adapter(*args):
+                return self.quitApplication()
             signal.signal(signal.SIGTERM, quit_adapter)
             if hasattr(signal, 'SIGHUP'):
                 forced_quit = lambda *args: self.quitApplication(force=True)
